==> classicperipherals-0.2.0-fabric-1.20.1-sources.jar: me/alexdevs/classicPeripherals/block/RfidScannerBlock.java <==
package me.alexdevs.classicPeripherals.block;

import dan200.computercraft.shared.peripheral.modem.ModemShapes;
import me.alexdevs.classicPeripherals.tiles.RfidScannerBlockEntity;
import net.minecraft.class_1750;
import net.minecraft.class_1922;
import net.minecraft.class_2248;
import net.minecraft.class_2318;
import net.minecraft.class_2338;
import net.minecraft.class_2343;
import net.minecraft.class_2350;
import net.minecraft.class_2415;
import net.minecraft.class_2470;
import net.minecraft.class_2586;
import net.minecraft.class_265;
import net.minecraft.class_2680;
import net.minecraft.class_2689;
import net.minecraft.class_2746;
import net.minecraft.class_3218;
import net.minecraft.class_3610;
import net.minecraft.class_3726;
import net.minecraft.class_4538;
import net.minecraft.class_5819;
import net.minecraft.world.level.block.*;
import org.jetbrains.annotations.Nullable;

public class RfidScannerBlock extends class_2318 implements class_2343 {
    public static final class_2746 ACTIVE = class_2746.method_11825("active");

    protected RfidScannerBlock(class_2251 properties) {
        super(properties);

        method_9590(method_9564()
                .method_11657(ACTIVE, false)
                .method_11657(field_10927, class_2350.field_11043)
        );
    }

    @Override
    protected void method_9515(class_2689.class_2690<class_2248, class_2680> builder) {
        builder.method_11667(field_10927, ACTIVE);
    }

    @Override
    public class_265 method_9530(class_2680 state, class_1922 level, class_2338 pos, class_3726 context) {
        return ModemShapes.getBounds(state.method_11654(field_10927));
    }

    @Override
    public class_3610 method_9545(class_2680 state) {
        return super.method_9545(state);
    }

    @Override
    public boolean method_9558(class_2680 state, class_4538 level, class_2338 pos) {
        var facing = state.method_11654(field_10927);
        return ModemShapes.canSupport(level, pos.method_10093(facing), facing.method_10153());
    }

    @Override
    public @Nullable class_2680 method_9605(class_1750 context) {
        return method_9564()
                .method_11657(field_10927, context.method_8038().method_10153());
    }

    @Override
    @Deprecated
    public class_2680 method_9569(class_2680 state, class_2415 mirrorIn) {
        return state.method_26186(mirrorIn.method_10345(state.method_11654(field_10927)));
    }

    @Override
    @Deprecated
    public class_2680 method_9598(class_2680 state, class_2470 rot) {
        return state.method_11657(field_10927, rot.method_10503(state.method_11654(field_10927)));
    }

    @Override
    public @Nullable class_2586 method_10123(class_2338 pos, class_2680 state) {
        return new RfidScannerBlockEntity(pos, state);
    }

    @Override
    public void method_9588(class_2680 state, class_3218 level, class_2338 pos, class_5819 random) {
        level.method_8501(pos, state.method_11657(ACTIVE, false));

        var be = level.method_8321(pos);
        if(be instanceof RfidScannerBlockEntity scanner) {
            if(!level.field_9236) {
                scanner.scan();
            }
        }
    }
}

==> classicperipherals-0.2.6-fabric-1.21.1-sources.jar: me/alexdevs/classicPeripherals/block/RfidScannerBlock.java <==
package me.alexdevs.classicPeripherals.block;

import com.mojang.serialization.MapCodec;
import dan200.computercraft.shared.peripheral.modem.ModemShapes;
import me.alexdevs.classicPeripherals.tiles.RfidScannerBlockEntity;
import net.minecraft.class_1750;
import net.minecraft.class_1922;
import net.minecraft.class_2248;
import net.minecraft.class_2318;
import net.minecraft.class_2338;
import net.minecraft.class_2343;
import net.minecraft.class_2350;
import net.minecraft.class_2415;
import net.minecraft.class_2470;
import net.minecraft.class_2586;
import net.minecraft.class_265;
import net.minecraft.class_2680;
import net.minecraft.class_2689;
import net.minecraft.class_2746;
import net.minecraft.class_3218;
import net.minecraft.class_3610;
import net.minecraft.class_3726;
import net.minecraft.class_4538;
import net.minecraft.class_5819;
import net.minecraft.world.level.block.*;
import org.jetbrains.annotations.Nullable;

public class RfidScannerBlock extends class_2318 implements class_2343 {
    public static final class_2746 ACTIVE = class_2746.method_11825("active");

    protected RfidScannerBlock(class_2251 properties) {
        super(properties);

        method_9590(method_9564()
                .method_11657(ACTIVE, false)
                .method_11657(field_10927, class_2350.field_11043)
        );
    }

    @Override
    protected MapCodec<? extends class_2318> method_53969() {
        return method_54094(RfidScannerBlock::new);
    }

    @Override
    protected void method_9515(class_2689.class_2690<class_2248, class_2680> builder) {
        builder.method_11667(field_10927, ACTIVE);
    }

    @Override
    public class_265 method_9530(class_2680 state, class_1922 level, class_2338 pos, class_3726 context) {
        return ModemShapes.getBounds(state.method_11654(field_10927));
    }

    @Override
    public class_3610 method_9545(class_2680 state) {
        return super.method_9545(state);
    }

    @Override
    public boolean method_9558(class_2680 state, class_4538 level, class_2338 pos) {
        var facing = state.method_11654(field_10927);
        return ModemShapes.canSupport(level, pos.method_10093(facing), facing.method_10153());
    }

    @Override
    public @Nullable class_2680 method_9605(class_1750 context) {
        return method_9564()
                .method_11657(field_10927, context.method_8038().method_10153());
    }

    @Override
    @Deprecated
    public class_2680 method_9569(class_2680 state, class_2415 mirrorIn) {
        return state.method_26186(mirrorIn.method_10345(state.method_11654(field_10927)));
    }

    @Override
    @Deprecated
    public class_2680 method_9598(class_2680 state, class_2470 rot) {
        return state.method_11657(field_10927, rot.method_10503(state.method_11654(field_10927)));
    }

    @Override
    public @Nullable class_2586 method_10123(class_2338 pos, class_2680 state) {
        return new RfidScannerBlockEntity(pos, state);
    }

    @Override
    public void method_9588(class_2680 state, class_3218 level, class_2338 pos, class_5819 random) {
        level.method_8501(pos, state.method_11657(ACTIVE, false));

        var be = level.method_8321(pos);
        if(be instanceof RfidScannerBlockEntity scanner) {
            if(!level.field_9236) {
                scanner.scan();
            }
        }
    }
}
